package info.aspirecn.iov.yysj.check.info.common;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import info.aspirecn.cloud.yysj.commons.lang.Constants;
import info.aspirecn.iov.yysj.paramtransfer.inter.common.Constant;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.ArrayUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.io.IOException;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.*;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

@Component
@Slf4j
public class TransferParam {

	private static final String DATE_YYYYMMDD = "(([0-9]{3}[1-9]|[0-9]{2}[1-9][0-9]{1}|[0-9]{1}[1-9][0-9]{2}|[1-9][0-9]{3})(((0[13578]|1[02])(0[1-9]|[12][0-9]|3[01]))|((0[469]|11)(0[1-9]|[12][0-9]|30))|(02(0[1-9]|[1][0-9]|2[0-8]))))|((([0-9]{2})(0[48]|[2468][048]|[13579][26])|((0[48]|[2468][048]|[3579][26])00))0229)";
	private static final String WEIGHT_000 = "([0-9]){0,}.[0-9]{3}";
	/*
	 * {"vehicleNumber":"新A93293","licensePlateTypeCode":"2","vehicleTonnage":"0"}
	 */
	@Autowired
	private Property property;

	public Map<String, Object> getCustomBody(Map<String, String> paramMap, String productId, Set<String> emptyList,
			Set<String> errorList) throws IOException, ResultCodeException {


		String allSpecialreg = "[`~!@#$%^&*()+=|{}':;',\\[\\].<>/?~！@#￥%……&*（）——+|{}【】‘；：”“’。，、？]+";
		Pattern allSpecialPattern = Pattern.compile(allSpecialreg);

		Map<String, Object> customBody = new HashMap<String, Object>();
		if ("01".equals(productId)) {// 行驶证验证

			customBody = clxszyz(paramMap, emptyList, errorList);
		}
		if ("03".equals(productId)) {// 驾驶证验证

			customBody = ryjszyz(paramMap, emptyList, errorList);
		}
		if ("04".equals(productId)) {// 人员从业资格验证

			customBody = rycyzgyz(paramMap, emptyList, errorList);
		}
		if ("02".equals(productId)) {// 车辆营运验证

			customBody = clyyyz(paramMap, emptyList, errorList);
		}
		if ("10".equals(productId)) {// 企业经营许可验证 经营许可证号

			customBody = qyyyxkyz(paramMap, emptyList, errorList);
		}
		if ("09".equals(productId)) {// 车辆入网验证

			customBody = clrwyz(paramMap, emptyList);
		}
		if ("07".equals(productId)) {// 托运人身份验证（个人）

			customBody = tyrsfyz_person(paramMap, emptyList);
		}
		if ("08".equals(productId)) {// 托运人身份验证（企业）

			customBody = tyrsfyz_enterprise(paramMap, emptyList);
		}
		if ("05".equals(productId)) {// 装货点车辆定位验证

			customBody = zhdwyz(paramMap, emptyList, errorList);
		}
		if ("06".equals(productId)) {// 卸货点车辆定位验证

			customBody = xhdwyz(paramMap, emptyList, errorList);
		}
		if ("12".equals(productId)) {// 超载验证（核载验证）

			customBody = czyz(paramMap, emptyList, errorList);
		}
		if ("13".equals(productId)) {// 司机上下线

			customBody = sjsxx(paramMap, emptyList, errorList);
		}
		if ("15".equals(productId) || "14".equals(productId)) {// 15 装卸货点车辆定位验证; 14车辆历史轨迹核验（车辆线上线下一致性验证）
			customBody=zxhdwyz(paramMap, emptyList, errorList);
		}
		if ("16".equals(productId)) {
			customBody = waybillHistoryPosition(paramMap, emptyList, errorList);
		} else if (Constants.OtherRquestUrl.IDLENTITYVERIFICATION.getValue().equals(productId)) {// 身份核验
			String req_id = paramMap.get(Constants.req_id);
			if (StringUtils.isEmpty(req_id)) {
				emptyList.add(Constants.req_id);
			}
			paramMap.clear();
			customBody.put("reqID", req_id);
			return customBody;
		} else if (Constants.OtherRquestUrl.LIVINGURL.getValue().equals(productId)) {// 身份核验
			String req_id = paramMap.get(Constants.req_id);
			if (StringUtils.isEmpty(req_id)) {
				emptyList.add(Constants.req_id);
			}
			String appe_id_code = paramMap.get(Constants.appe_id_code);
			if (StringUtils.isEmpty(appe_id_code)) {
				emptyList.add(Constants.appe_id_code);
			}
			String eid_voucher = paramMap.get(Constants.eid_voucher);
			if (StringUtils.isEmpty(eid_voucher)) {
				emptyList.add(Constants.eid_voucher);
			}
			String longitudeDegree = paramMap.get(Constants.Long_degree);

			String lat_degree = paramMap.get(Constants.lat_degree);
			paramMap.clear();
			customBody.put("reqID", req_id);
			customBody.put("appeIdCode", appe_id_code);
			customBody.put("eidVoucher", eid_voucher);
			if (StringUtils.isNotEmpty(longitudeDegree)) {
				customBody.put("longitudeDegree", longitudeDegree);
			}
			if (StringUtils.isNotEmpty(lat_degree)) {
				customBody.put("latitudeDegree", lat_degree);
			}

			return customBody;
		}else if(Constants.RoadTransportUrl.CarRoadTransport.getValue().equals(productId)){//车辆运输验证

			/**车牌号校验正则表达式*/


			String vehicleNumberReg = "[`~!@#$%^&*()+=|{}':;',\\[\\].<>/?~！@#￥%……&*（）+|{}【】‘；：”“’。，、？]+";
			Pattern vehicleNumberPattern = Pattern.compile(vehicleNumberReg);
			String vehicleNumber=paramMap.get(Constants.carck_vehicleNumber);
            if(StringUtils.isEmpty(vehicleNumber)) {
                emptyList.add(Constants.carck_vehicleNumber);
            }else if(vehicleNumber.replace(" ","").length()<1 || vehicleNumber.length()>35){
				errorList.add(Constants.carck_vehicleNumber);
			}else if(vehicleNumberPattern.matcher(vehicleNumber).matches()){
				errorList.add(Constants.carck_vehicleNumber);
			}

            String colorCode=paramMap.get(Constants.carck_colorCode);
            if(StringUtils.isEmpty(colorCode)) {
                emptyList.add(Constants.carck_colorCode);
            }else if(colorCode.replace(" ","").length()<1||!checkColor(colorCode)){
				errorList.add(Constants.carck_colorCode);
			}
            String certificateNumber=paramMap.get(Constants.carck_certificateNumber);

            String vin=paramMap.get(Constants.carck_vin);
            if(StringUtils.isEmpty(certificateNumber)&&StringUtils.isEmpty(vin)) {
            	  emptyList.add(Constants.carck_certificateNumber);
            	  emptyList.add(Constants.carck_vin);
            }

			if(StringUtils.isNotEmpty(certificateNumber)&&StringUtils.isNotEmpty(vin)) {
				throw  new ResultCodeException(Constants.ResultDesc.PARAMERROR.getCode(),"车辆识别代号与道路运输证号只允许出现其一","certificateNumber与vin只允许出现其一");
			}

			String certificateNumberReg = "[0-9a-zA-Z]{1,20}";
			Pattern certificateNumberPattern = Pattern.compile(certificateNumberReg);
			if(StringUtils.isNotEmpty(certificateNumber)) {
				log.info("{}",certificateNumberPattern.matcher(certificateNumber).matches());
				if (!certificateNumberPattern.matcher(certificateNumber).matches()) {
					errorList.add(Constants.carck_certificateNumber);
				}
			}
			String vinReg = "[0-9a-zA-Z]{1,32}";
			Pattern vinPattern = Pattern.compile(vinReg);
			if(StringUtils.isNotEmpty(vin)) {
				log.info("{}",certificateNumberPattern.matcher(vin).matches());
				if (!vinPattern.matcher(vin).matches()) {
					errorList.add(Constants.carck_vin);
				}
			}



            return new HashMap(paramMap);
        }
		else if(Constants.RoadTransportUrl.PersonRoadTransport.getValue().equals(productId)){//身份核验
			/**中文姓名校验正则表达式*/
			String CN_NAME_REGEX = "^[\\u4E00-\\u9FA5\\uf900-\\ufa2d·s]{2,30}$";
			Pattern pattern = Pattern.compile(CN_NAME_REGEX);
            String driverName=paramMap.get(Constants.perck_driverName);
            if(StringUtils.isEmpty(driverName)) {
                emptyList.add(Constants.perck_driverName);
            }/*else if(driverName.replace(" ","").length()<1||driverName.length()>30){
				errorList.add(Constants.perck_driverName);
			}*/else if(!pattern.matcher(driverName).matches()){
				errorList.add(Constants.perck_driverName);
			}

            String drivingLicense=paramMap.get(Constants.perck_drivingLicense);
            String certificate=paramMap.get(Constants.perck_certificate);
			if(StringUtils.isNotEmpty(drivingLicense)&&StringUtils.isNotEmpty(certificate)) {
				throw  new ResultCodeException(Constants.ResultDesc.PARAMERROR.getCode(),"从业资格证号与身份证号只允许出现其一","drivingLicense与certificate只允许出现其一");
			}
            if(StringUtils.isEmpty(drivingLicense) && StringUtils.isEmpty(certificate)) {
                emptyList.add(Constants.perck_drivingLicense);
                emptyList.add(Constants.perck_certificate);
            }else if(StringUtils.isNotEmpty(drivingLicense)){
				String IDENTITY_REGEX = "^[1-9]\\d{7}((0\\d)|(1[0-2]))(([0|1|2]\\d)|3[0-1])\\d{3}$|^[1-9]\\d{5}[1-9]\\d{3}((0\\d)|(1[0-2]))(([0|1|2]\\d)|3[0-1])\\d{3}([0-9]|X)$";
				Pattern patternID = Pattern.compile(IDENTITY_REGEX);

				 /*if(drivingLicense.replace(" ","").length()<1||drivingLicense.length()>18){
					errorList.add(Constants.perck_drivingLicense);
				}*/if(!patternID.matcher(drivingLicense).matches()){
					errorList.add(Constants.perck_drivingLicense);
				}else{
					 customBody.put(Constants.up_drivingLicense, drivingLicense);
				 }


			}else if(StringUtils.isNotEmpty(certificate)){

				if(certificate.replace(" ","").length()<1||certificate.length()>18||allSpecialPattern.matcher(certificate).matches()){
					errorList.add(Constants.perck_certificate);
				}else{
					customBody.put(Constants.up_certificate, certificate);
				}

			}



            String provinceCode=paramMap.get(Constants.perck_provinceCode);


            if(StringUtils.isEmpty(provinceCode)) {
            	  emptyList.add(Constants.perck_provinceCode);

            }else if(provinceCode.replace(" ","").length()<1||provinceCode.length()>6||!checkProvince(provinceCode)){
				errorList.add(Constants.perck_provinceCode);
			}
				paramMap.clear();
			customBody.put(Constants.up_driverName, driverName);


			customBody.put(Constants.up_provinceCode, provinceCode);

            return customBody;
        }else if(Constants.RoadTransportUrl.CompanyRoadTransport.getValue().equals(productId)){//身份核验
            String name=paramMap.get(Constants.comck_name);
			if(StringUtils.isNotEmpty(name)) {
				if(name.replace(" ","").length()<1||name.length()>50){
					errorList.add(Constants.comck_name);
				}else {
					customBody.put(Constants.up_name, name);
				}

			}

            String permitNumber=paramMap.get(Constants.comck_permitNumber);

            if(StringUtils.isEmpty(permitNumber)) {
                emptyList.add(Constants.comck_permitNumber);

            }else if(permitNumber.replace(" ","").length()<1||permitNumber.length()>50||allSpecialPattern.matcher(permitNumber).matches()){
				errorList.add(Constants.comck_permitNumber);
			}
            String provinceCode=paramMap.get(Constants.comck_provinceCode);


            if(StringUtils.isEmpty(provinceCode)) {
            	  emptyList.add(Constants.comck_provinceCode);

            }else if(provinceCode.replace(" ","").length()<1||provinceCode.length()>6||!checkProvince(provinceCode)){
				errorList.add(Constants.comck_provinceCode);
			}
			paramMap.clear();

			customBody.put(Constants.up_permitNumber, permitNumber);
			customBody.put(Constants.up_cprovinceCode, provinceCode);

			return customBody;
        }
		return customBody;
	}

	// 校验项一 车辆行驶证验证 行驶证信息查询查询
	public Map<String, Object> clxszyz(Map<String, String> requestMap, Set<String> emptyList, Set<String> errorList)
			throws IOException, ResultCodeException {
		String vehicleNumber = requestMap.get(Constants.car_vehicleNumber);
		String vehicleType = requestMap.get(Constants.car_vehicleType);
		String owner = requestMap.get(Constants.car_owner);
		String vin = requestMap.get(Constants.car_vin);
		String registerDate = requestMap.get(Constants.car_registerDate);
		if (StringUtils.isEmpty(vehicleNumber)) {
			emptyList.add(Constants.car_vehicleNumber);
		}
		if (StringUtils.isEmpty(vin)) {
			emptyList.add(Constants.car_vin);
		}
		if (StringUtils.isEmpty(vehicleType)) {
			emptyList.add(Constants.car_vehicleType);
		}
		Pattern pattern = Pattern.compile(DATE_YYYYMMDD);
		if (StringUtils.isEmpty(registerDate)) {
			emptyList.add(Constants.car_registerDate);
		} else if (!pattern.matcher(registerDate).matches()) {
			errorList.add(Constants.car_registerDate);
		}

		if (StringUtils.isEmpty(owner)) {
			emptyList.add(Constants.car_owner);
		}
		if (emptyList.size() == 0 && errorList.size() == 0) {

			Map<String, Object> vehicleInfoMap = new HashMap<String, Object>();
			vehicleInfoMap.put(Constants.clxszyz_carNumber, vehicleNumber);
			vehicleInfoMap.put(Constants.clxszyz_carType, vehicleType);
			vehicleInfoMap.put(Constants.clxszyz_name, owner);
			vehicleInfoMap.put(Constants.car_vin, vin);
			vehicleInfoMap.put(Constants.car_registerDate, registerDate);
			return vehicleInfoMap;
		}
		return null;

	}

	// 校验项二 人员驾驶证验证
	public Map<String, Object> ryjszyz(Map<String, String> requestMap, Set<String> emptyList, Set<String> errorList)
			throws IOException, ResultCodeException {
		String vehicleNumber = requestMap.get(Constants.driver_driverLicenseNumber);
		String name = requestMap.get(Constants.driver_driverNamer);
		String vehicleClass = requestMap.get(Constants.driver_vehicleClass);
		String validPeriodFrom = requestMap.get(Constants.driver_validPeriodFrom);
		String validPeriodTo = requestMap.get(Constants.driver_validPeriodTo);
		Pattern pattern = Pattern.compile(DATE_YYYYMMDD);
		if (StringUtils.isEmpty(vehicleNumber)) {
			emptyList.add(Constants.driver_driverLicenseNumber);
		}
		if (StringUtils.isEmpty(name)) {
			emptyList.add(Constants.driver_driverNamer);
		}
		if (StringUtils.isEmpty(vehicleClass)) {
			emptyList.add(Constants.driver_vehicleClass);
		}
		if (StringUtils.isEmpty(validPeriodFrom)) {
			emptyList.add(Constants.driver_validPeriodFrom);
		} else if (!pattern.matcher(validPeriodFrom).matches()) {
			errorList.add(Constants.driver_validPeriodFrom);
		}
		if (StringUtils.isEmpty(validPeriodTo)) {
			emptyList.add(Constants.driver_validPeriodTo);
		} else if (!pattern.matcher(validPeriodTo).matches()) {
			errorList.add(Constants.driver_validPeriodTo);
		}
		/*
		 * if ((!StringUtils.isEmpty(validPeriodFrom) &&
		 * !pattern.matcher(validPeriodFrom).matches()) ||
		 * (!StringUtils.isEmpty(validPeriodTo) &&
		 * !pattern.matcher(validPeriodTo).matches())) { throw new
		 * ResultCodeException(Constants.ResultDesc.PARAMERROR.getCode(),
		 * Constants.ResultDesc.PARAMERROR.getValue(), "驾驶证开始结束时间不正确"); }
		 */
		if (emptyList.size() == 0 && errorList.size() == 0) {

			Map<String, Object> vehicleInfoMap = new HashMap<String, Object>();
			vehicleInfoMap.put(Constants.ryjszyz_driveNo, vehicleNumber);
			vehicleInfoMap.put(Constants.ryjszyz_name, name);
			vehicleInfoMap.put(Constants.driver_vehicleClass, vehicleClass);
			vehicleInfoMap.put(Constants.driver_validPeriodFrom, validPeriodFrom);
			vehicleInfoMap.put(Constants.driver_validPeriodTo, validPeriodTo);
			return vehicleInfoMap;
		}
		return null;
	}

	/*
	 * 校验行三 人员从业资格验证 查询人员信息接口
	 */
	public Map<String, Object> rycyzgyz(Map<String, String> requestMap, Set<String> emptyList, Set<String> errorList)
			throws IOException, ResultCodeException {
		String driverName = requestMap.get(Constants.driver_driverNamer);
		String qualificationCertificate = requestMap.get(Constants.driver_qualificationCertificate);
		String provinceCode = requestMap.get(Constants.driver_provinceCode);
		String qualificationCertificateFrom = requestMap.get(Constants.driver_qualificationCertificateFrom);
		String qualificationCertificateTo = requestMap.get(Constants.driver_qualificationCertificateTo);
		Pattern pattern = Pattern.compile(DATE_YYYYMMDD);
		if (StringUtils.isEmpty(driverName)) {
			emptyList.add(Constants.driver_driverNamer);
		}
		if (StringUtils.isEmpty(qualificationCertificate)) {
			emptyList.add(Constants.driver_qualificationCertificate);
		}
		if (StringUtils.isEmpty(provinceCode)) {
			emptyList.add(Constants.driver_provinceCode);
		}
		if (StringUtils.isEmpty(qualificationCertificateFrom)) {
			emptyList.add(Constants.driver_qualificationCertificateFrom);
		} else if (!pattern.matcher(qualificationCertificateFrom).matches()) {
			errorList.add(Constants.driver_qualificationCertificateFrom);
		}
		if (StringUtils.isEmpty(qualificationCertificateTo)) {
			emptyList.add(Constants.driver_qualificationCertificateTo);
		} else if (!pattern.matcher(qualificationCertificateTo).matches()) {
			errorList.add(Constants.driver_qualificationCertificateTo);
		}
		if (emptyList.size() == 0 && errorList.size() == 0) {
			Map<String, Object> vehicleInfoMap = new HashMap<String, Object>();
			vehicleInfoMap.put(Constants.rycyzgyz_nameOfPerson, driverName);
			vehicleInfoMap.put(Constants.rycyzgyz_qualificationCertificateNumber, qualificationCertificate);
			vehicleInfoMap.put(Constants.rycyzgyz_provinceCode, provinceCode);
			vehicleInfoMap.put(Constants.rycyzgyz_periodStartDate, qualificationCertificateFrom);
			vehicleInfoMap.put(Constants.rycyzgyz_periodEndDate, qualificationCertificateTo);
			return vehicleInfoMap;
		}
		return null;
	}

	/*
	 * 校验项四 车辆营运验证
	 */
	public Map<String, Object> clyyyz(Map<String, String> requestMap, Set<String> emptyList, Set<String> errorList)
			throws IOException, ResultCodeException {
		String vehicleNumber = requestMap.get(Constants.car_vehicleNumber);
		String roadTransportCertificateNumber = requestMap.get(Constants.car_roadTransport);
		String vehiclePlateColorCode = requestMap.get(Constants.car_vehiclePlateColorCode);
		String roadTransportCertificateValidPeriodFrom = requestMap
				.get(Constants.car_roadTransportCertificateValidPeriodFrom);
		String roadTransportCertificateValidPeriodTo = requestMap
				.get(Constants.car_roadTransportCertificateValidPeriodTo);
		if (StringUtils.isEmpty(vehicleNumber)) {
			emptyList.add(Constants.car_vehicleNumber);
		}
		if (StringUtils.isEmpty(roadTransportCertificateNumber)) {
			emptyList.add(Constants.car_roadTransport);
		}
		if (StringUtils.isEmpty(vehiclePlateColorCode)) {
			emptyList.add(Constants.car_vehiclePlateColorCode);
		}
		Pattern pattern = Pattern.compile(DATE_YYYYMMDD);
		if (StringUtils.isEmpty(roadTransportCertificateValidPeriodFrom)) {
			emptyList.add(Constants.car_roadTransportCertificateValidPeriodFrom);
		} else if (!pattern.matcher(roadTransportCertificateValidPeriodFrom).matches()) {
			errorList.add(Constants.car_roadTransportCertificateValidPeriodFrom);
		}
		if (StringUtils.isEmpty(roadTransportCertificateValidPeriodTo)) {
			emptyList.add(Constants.car_roadTransportCertificateValidPeriodTo);
		} else if (!pattern.matcher(roadTransportCertificateValidPeriodTo).matches()) {
			errorList.add(Constants.car_roadTransportCertificateValidPeriodTo);
		}
		if (emptyList.size() == 0 && errorList.size() == 0) {
			Map<String, Object> vehicleInfoMap = new HashMap<String, Object>();
			vehicleInfoMap.put(Constants.clyyyz_vehicleNumber, vehicleNumber);
			vehicleInfoMap.put(Constants.clyyyz_roadTransportCertificateNumber, roadTransportCertificateNumber);
			vehicleInfoMap.put(Constants.clyyyz_licensePlateTypeCode, vehiclePlateColorCode);
			vehicleInfoMap.put(Constants.clyyyz_periodStartDate, roadTransportCertificateValidPeriodFrom);
			vehicleInfoMap.put(Constants.clyyyz_periodEndDate, roadTransportCertificateValidPeriodTo);
			return vehicleInfoMap;
		}
		return null;
	}

	public Map<String, Object> qyyyxkyz(Map<String, String> requestMap, Set<String> emptyList, Set<String> errorList)
			throws IOException, ResultCodeException {
		String carrier = requestMap.get(Constants.bill_carrier);
		String permitNumber = requestMap.get(Constants.bill_permitNumber);
		// String
		// unifiedSocialCreditIdentifier=requestMap.get(Constants.bill_unifiedSocialCreditIdentifier);
		/*
		 * String
		 * permitValidPeriodFrom=requestMap.get(Constants.bill_permitValidPeriodFrom);
		 * String
		 * permitValidPeriodTo=requestMap.get(Constants.bill_permitValidPeriodTo);
		 * Pattern pattern = Pattern.compile(DATE_YYYYMMDD);
		 */
		if (StringUtils.isEmpty(carrier)) {
			emptyList.add(Constants.bill_carrier);
		}
		if (StringUtils.isEmpty(permitNumber)) {
			emptyList.add(Constants.bill_permitNumber);
		}

		/*
		 * if(StringUtils.isEmpty(permitValidPeriodFrom)){
		 * emptyList.add(Constants.bill_permitValidPeriodFrom); }else
		 * if(!pattern.matcher(permitValidPeriodFrom).matches()){
		 * errorList.add(Constants.bill_permitValidPeriodFrom); }
		 * if(StringUtils.isEmpty(permitValidPeriodTo)){
		 * emptyList.add(Constants.bill_permitValidPeriodTo); }else
		 * if(!pattern.matcher(permitValidPeriodTo).matches()){
		 * errorList.add(Constants.bill_permitValidPeriodTo); }
		 * if(StringUtils.isEmpty(unifiedSocialCreditIdentifier)){
		 * emptyList.add(Constants.bill_unifiedSocialCreditIdentifier); }
		 */
		if (emptyList.size() == 0 && errorList.size() == 0) {
			Map<String, Object> vehicleInfoMap = new HashMap<String, Object>();
			vehicleInfoMap.put(Constants.bill_carrier, carrier);
			vehicleInfoMap.put(Constants.bill_permitNumber, permitNumber);
			/*
			 * vehicleInfoMap.put(Constants.bill_unifiedSocialCreditIdentifier,
			 * unifiedSocialCreditIdentifier);
			 * vehicleInfoMap.put(Constants.bill_permitValidPeriodFrom,
			 * permitValidPeriodFrom);
			 * vehicleInfoMap.put(Constants.bill_permitValidPeriodTo, permitValidPeriodTo);
			 */
			return vehicleInfoMap;
		}
		return null;
	}

	// 校验项六 车辆入网验证
	public Map<String, Object> clrwyz(Map<String, String> requestMap, Set<String> emptyList)
			throws IOException, ResultCodeException {

		Object vehicleInfo = requestMap.get(Constants.bill_vehicleInfo);
		String vehicleNumber = "";
		String vehiclePlateColorCode = "";
		if (vehicleInfo == null || !(vehicleInfo instanceof LinkedHashMap)) {
			emptyList.add(Constants.bill_vehicleInfo);
		} else if (vehicleInfo instanceof LinkedHashMap) {
			Map<String, String> vehicleInfoMap = (Map) vehicleInfo;
			vehicleNumber = vehicleInfoMap.get(Constants.bill_vehicleNumber);
			if (StringUtils.isEmpty(vehicleNumber)) {
				emptyList.add(Constants.bill_vehicleInfo + "." + Constants.bill_vehicleNumber);
			}
			vehiclePlateColorCode = vehicleInfoMap.get(Constants.bill_vehiclePlateColorCode);
			if (StringUtils.isEmpty(vehiclePlateColorCode)) {
				emptyList.add(Constants.bill_vehicleInfo + "." + Constants.bill_vehiclePlateColorCode);
			}
		}
		if (emptyList.size() == 0) {
			Map<String, Object> vehicleInfoMap = new HashMap<String, Object>();
			vehicleInfoMap.put(Constants.clrw_vehicleNumber, vehicleNumber);
			vehicleInfoMap.put(Constants.clrw_licensePlateTypeCode, vehiclePlateColorCode);
			return vehicleInfoMap;
		}
		return null;
	}

	// 校验项七 托运人身份验证（个人）
	public Map<String, Object> tyrsfyz_person(Map<String, String> requestMap, Set<String> emptyList)
			throws IOException, ResultCodeException {
		Object consignorInfo = requestMap.get(Constants.bill_consignorInfo);
		String consignor = "";
		String consignorID = "";
		if (consignorInfo == null) {
			emptyList.add(Constants.bill_consignorInfo);
		} else {
			if (consignorInfo instanceof LinkedHashMap) {
				Map<String, String> consignorInfoMap = (Map) consignorInfo;
				consignor = consignorInfoMap.get(Constants.bill_consignor);
				consignorID = consignorInfoMap.get(Constants.bill_ConsignorID);
			}
			if (StringUtils.isEmpty(consignor)) {
				emptyList.add(Constants.bill_consignorInfo + "." + Constants.bill_consignor);
			}
			if (StringUtils.isEmpty(consignorID)) {
				emptyList.add(Constants.bill_consignorInfo + "." + Constants.bill_ConsignorID);
			}
			if (emptyList.size() == 0) {
				Map<String, Object> infoMap = new HashMap<String, Object>();
				infoMap.put(Constants.persontyr_name, consignor);
				infoMap.put(Constants.persontyr_idCode, consignorID);
				return infoMap;
			}
		}
		return null;
	}

	// 校验项八 托运人身份验证（企业）
	public Map<String, Object> tyrsfyz_enterprise(Map<String, String> requestMap, Set<String> emptyList)
			throws IOException, ResultCodeException {
		Object consignorInfo = requestMap.get(Constants.bill_consignorInfo);
		String consignor = "";
		String consignorID = "";
		if (consignorInfo instanceof LinkedHashMap) {
			Map<String, String> consignorInfoMap = (Map) consignorInfo;
			consignor = consignorInfoMap.get(Constants.bill_consignor);
			consignorID = consignorInfoMap.get(Constants.bill_ConsignorID);
		}
		if (StringUtils.isEmpty(consignor)) {
			emptyList.add(Constants.bill_consignorInfo + "." + Constants.bill_consignor);
		}
		if (StringUtils.isEmpty(consignorID)) {
			emptyList.add(Constants.bill_consignorInfo + "." + Constants.bill_ConsignorID);
		}
		if (emptyList.size() == 0) {
			Map<String, Object> infoMap = new HashMap<String, Object>();
			infoMap.put(Constants.bill_carrier, consignor);
			// infoMap.put(Constants.enterpricetyr_creditCode, consignorID);
			return infoMap;
		}
		return null;
	}

	// 校验项六 装货点车辆定位验证
	public Map<String, Object> zhdwyz(Map<String, String> requestMap, Set<String> emptyList, Set<String> errorList)
			throws IOException, ResultCodeException {
		Object vehicleInfo = requestMap.get(Constants.bill_vehicleInfo);
		String vehicleNumber = "";
		Map<String, Object> resultMap = new HashMap<String, Object>();
		String countrySubdivisionCode = "";
		if (vehicleInfo == null || !(vehicleInfo instanceof LinkedHashMap)) {
			emptyList.add(Constants.bill_vehicleInfo);
		} else if (vehicleInfo instanceof LinkedHashMap) {
			Map<String, String> vehicleInfoMap = (Map) vehicleInfo;
			vehicleNumber = vehicleInfoMap.get(Constants.bill_vehicleNumber);
			if (StringUtils.isEmpty(vehicleNumber)) {
				emptyList.add(Constants.bill_vehicleInfo + "." + Constants.bill_vehicleNumber);
			}
		}
		Object consignorInfo = requestMap.get(Constants.bill_consignorInfo);
		if (consignorInfo == null || !(consignorInfo instanceof LinkedHashMap)) {
			emptyList.add(Constants.bill_consignorInfo);
		} else if (consignorInfo instanceof LinkedHashMap) {
			Map<String, String> consignorInfoMap = (Map) consignorInfo;
			countrySubdivisionCode = consignorInfoMap.get(Constants.bill_countrySubdivisionCode);
			if (StringUtils.isEmpty(countrySubdivisionCode)) {
				emptyList.add(Constants.bill_consignorInfo + "." + Constants.bill_countrySubdivisionCode);
			}
		}
		String despatchActualDateTime = requestMap.get(Constants.bill_despatchActualDateTime);

		if (StringUtils.isEmpty(despatchActualDateTime)) {
			emptyList.add(Constants.bill_despatchActualDateTime);
		} else if (!checkDateTime(despatchActualDateTime, "yyyyMMddHHmmss")) {
			errorList.add(Constants.bill_despatchActualDateTime);
		}
		if (emptyList.size() == 0 && errorList.size() == 0) {
			resultMap.put(Constants.zh_xh_vehicleNumber, vehicleNumber);
			resultMap.put(Constants.zh_xh_countrySubdivisionCode, countrySubdivisionCode);
			resultMap.put(Constants.zh_xh_dateTime,
					transferDate(despatchActualDateTime, "yyyyMMddHHmmss", "yyyy-MM-dd HH:mm:ss"));
			return resultMap;
		}
		return null;

	}

	// 校验项六 卸货点车辆定位验证
	public Map<String, Object> xhdwyz(Map<String, String> requestMap, Set<String> emptyList, Set<String> errorList)
			throws IOException, ResultCodeException {
		Object vehicleInfo = requestMap.get(Constants.bill_vehicleInfo);
		String vehicleNumber = "";
		Map<String, Object> resultMap = new HashMap<String, Object>();
		String countrySubdivisionCode = "";
		if (vehicleInfo == null || !(vehicleInfo instanceof LinkedHashMap)) {
			emptyList.add(Constants.bill_vehicleInfo);
		} else if (vehicleInfo instanceof LinkedHashMap) {
			Map<String, String> vehicleInfoMap = (Map) vehicleInfo;
			vehicleNumber = vehicleInfoMap.get(Constants.bill_vehicleNumber);
			if (StringUtils.isEmpty(vehicleNumber)) {
				emptyList.add(Constants.bill_vehicleInfo + "." + Constants.bill_vehicleNumber);
			}
		}
		Object consigneeInfo = requestMap.get(Constants.bill_consigneeInfo);
		if (consigneeInfo == null || !(consigneeInfo instanceof LinkedHashMap)) {
			emptyList.add(Constants.bill_consigneeInfo);
		} else if (consigneeInfo instanceof LinkedHashMap) {
			Map<String, String> consigneeInfoMap = (Map) consigneeInfo;
			countrySubdivisionCode = consigneeInfoMap.get(Constants.bill_countrySubdivisionCode);
			if (StringUtils.isEmpty(countrySubdivisionCode)) {
				emptyList.add(Constants.bill_consigneeInfo + "." + Constants.bill_countrySubdivisionCode);
			}
		}
		String goodsReceiptDateTime = requestMap.get(Constants.bill_goodsReceiptDateTime);

		if (StringUtils.isEmpty(goodsReceiptDateTime)) {
			emptyList.add(Constants.bill_goodsReceiptDateTime);
		} else if (!checkDateTime(goodsReceiptDateTime, "yyyyMMddHHmmss")) {
			errorList.add(Constants.bill_goodsReceiptDateTime);
		}
		if (emptyList.size() == 0 && errorList.size() == 0) {
			resultMap.put(Constants.zh_xh_vehicleNumber, vehicleNumber);
			resultMap.put(Constants.zh_xh_countrySubdivisionCode, countrySubdivisionCode);
			resultMap.put(Constants.zh_xh_dateTime,
					transferDate(goodsReceiptDateTime, "yyyyMMddHHmmss", "yyyy-MM-dd HH:mm:ss"));

			return resultMap;
		}
		return null;

	}

	// 校验项六 超载验证（核载验证）
	public Map<String, Object> czyz(Map<String, String> requestMap, Set<String> emptyList, Set<String> errorList)
			throws IOException, ResultCodeException {
		Object vehicleInfo = requestMap.get(Constants.bill_vehicleInfo);
		String vehicleNumber = "";
		String vehiclePlateColorCode = "";
		double weightTotal = 0.0;
		Map<String, Object> resultMap = new HashMap<String, Object>();
		if (vehicleInfo == null || !(vehicleInfo instanceof LinkedHashMap)) {
			emptyList.add(Constants.bill_vehicleInfo);
		} else if (vehicleInfo instanceof LinkedHashMap) {
			Map<String, String> vehicleInfoMap = (Map) vehicleInfo;
			vehicleNumber = vehicleInfoMap.get(Constants.bill_vehicleNumber);
			if (StringUtils.isEmpty(vehicleNumber)) {
				emptyList.add(Constants.bill_vehicleInfo + "." + Constants.bill_vehicleNumber);
			}
			vehiclePlateColorCode = vehicleInfoMap.get(Constants.car_vehiclePlateColorCode);
			if (StringUtils.isEmpty(vehiclePlateColorCode)) {
				emptyList.add(Constants.bill_vehicleInfo + "." + Constants.car_vehiclePlateColorCode);
			}
			Object goodsInfos = vehicleInfoMap.get(Constants.bill_goodsInfo);
			if (goodsInfos == null) {
				emptyList.add(Constants.bill_vehicleInfo + "." + Constants.bill_goodsInfo);
			} else {
				Pattern pattern = Pattern.compile(WEIGHT_000);
				if (goodsInfos instanceof ArrayList) {
					List<Object> goodInfoList = (List) goodsInfos;
					for (Object goodInfo : goodInfoList) {
						if (goodInfo instanceof LinkedHashMap) {
							Map<String, String> goodInfoMap = (Map<String, String>) goodInfo;
							String weightStr = goodInfoMap.get(Constants.bill_goodsInfo_weight);

							Matcher matcher = pattern.matcher(weightStr);
							if (!matcher.matches()) {
								errorList.add(Constants.bill_vehicleInfo + "." + Constants.bill_goodsInfo + "."
										+ Constants.bill_goodsInfo_weight);
								break;
							}
							double weight = Double.parseDouble(weightStr);
							weightTotal += weight;
						} else {
							errorList.add(Constants.bill_vehicleInfo + "." + Constants.bill_goodsInfo + "."
									+ Constants.bill_goodsInfo_weight);
						}
					}

				} else {
					errorList.add(Constants.bill_vehicleInfo + "." + Constants.bill_goodsInfo);
				}
			}

		}
		if (emptyList.size() == 0 && errorList.size() == 0) {
			resultMap.put(Constants.zlhy_vehicleNumber, vehicleNumber);
			resultMap.put(Constants.zlhy_licensePlateTypeCode, vehiclePlateColorCode);
			resultMap.put(Constants.zlhy_vehicleTonnage, String.valueOf(weightTotal));
			return resultMap;
		}
		return null;

	}

	// 校验项十四 司机上下线
	public Map<String, Object> sjsxx(Map<String, String> requestMap, Set<String> emptyList, Set<String> errorList)
			throws IOException, ResultCodeException {
		String shippingNoteNumber = requestMap.get(Constants.bill_shipping_note_number);
		if (StringUtils.isEmpty(shippingNoteNumber)) {
			emptyList.add(Constants.bill_shipping_note_number);
		}
		String despatchActualDateTime = requestMap.get(Constants.bill_despatchActualDateTime);
		if (StringUtils.isEmpty(despatchActualDateTime)) {
			emptyList.add(Constants.bill_despatchActualDateTime);
		} else {
			try {
				SimpleDateFormat yMdHms = new SimpleDateFormat("yyyyMMddHHmmss");
				SimpleDateFormat yMdHmsResult = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
				despatchActualDateTime = yMdHmsResult.format(yMdHms.parse(despatchActualDateTime));
			} catch (ParseException ex) {
				log.error("解析发货时间异常:{}", ex);
				errorList.add(Constants.bill_despatchActualDateTime);
			}
		}

		String driverName = "";
		String driverLicense = "";
		List<Map> resultDriver = new ArrayList<Map>();
		Object vehicleInfo = requestMap.get(Constants.bill_vehicleInfo);
		Map<String, Object> resultMap = new HashMap<String, Object>();
		if (vehicleInfo == null || !(vehicleInfo instanceof LinkedHashMap)) {
			emptyList.add(Constants.bill_vehicleInfo);
		} else if (vehicleInfo instanceof LinkedHashMap) {
			Map<String, String> vehicleInfoMap = (Map) vehicleInfo;
			Object drivers = vehicleInfoMap.get(Constants.bill_driver);

			if (drivers == null || !(drivers instanceof ArrayList)) {
				emptyList.add(Constants.bill_vehicleInfo + "." + Constants.bill_driver);
			} else if (drivers instanceof ArrayList) {
				List<Object> driverList = (List) drivers;
				if (driverList.size() < 1) {
					emptyList.add(Constants.bill_vehicleInfo + "." + Constants.bill_driver);
				} else {
					for (Object driverInfo : driverList) {
						Map<String, String> driverMap = new HashMap<String, String>();
						if (driverInfo instanceof LinkedHashMap) {
							Map<String, String> driverInfoMap = (Map<String, String>) driverInfo;
							driverName = driverInfoMap.get(Constants.bill_driver_name);
							if (StringUtils.isEmpty(driverName)) {
								emptyList.add(Constants.bill_vehicleInfo + "." + Constants.bill_driver + "."
										+ Constants.bill_driver_name);
								break;
							}
							driverLicense = driverInfoMap.get(Constants.bill_driver_License);
							if (StringUtils.isEmpty(driverLicense)) {
								emptyList.add(Constants.bill_vehicleInfo + "." + Constants.bill_driver + "."
										+ Constants.bill_driver_License);
								break;
							}
							driverMap.put(Constants.sjsxx_name, driverName);
							driverMap.put(Constants.sjsxx_idCode, driverLicense);
							resultDriver.add(driverMap);
						} else {
							errorList.add(Constants.bill_vehicleInfo + "." + Constants.bill_driver);
						}
					}
				}

			}
		}
		if (emptyList.size() == 0 && errorList.size() == 0) {
			resultMap.put(Constants.sjsxx_bill_no, shippingNoteNumber);

			resultMap.put(Constants.sjsxx_drivers, resultDriver);
			resultMap.put(Constants.sjsxx_despatchActualDateTime, despatchActualDateTime);
			return resultMap;
		}
		return null;

	}

	//校验项十五	装卸货点车辆定位验证
	public Map<String,Object> zxhdwyz(Map<String,String> requestMap, Set<String> emptyList,Set<String> errorList) throws IOException, ResultCodeException {
		// 车牌号
		String vehicleNumber = requestMap.get(Constants.bill_vehicleNumber);
		// 车牌颜色
		String vehiclePlateColorCode = requestMap.get(Constants.bill_vehiclePlateColorCode);
		// 收货地址的国家行政区划代码
		String receiptCountrySubdivisionCode = requestMap.get(Constants.bill_receipt_country_subdivision_code);
		// 收货日期时间
		String goodsReceiptDateTime = requestMap.get(Constants.bill_goodsReceiptDateTime);
		// 装货地址的国家行政区划代码
		String loadingCountrySubdivisionCode = requestMap.get(Constants.bill_loading_country_subdivision_code);
		// 发货日期时间
		String despatchActualDateTime = requestMap.get(Constants.bill_despatchActualDateTime);
		// 运单号
		String shippingNoteNumber = requestMap.get(Constants.bill_shipping_note_number);
		// 装货地址
		String placeOfLoading = requestMap.get(Constants.bill_place_of_loading);
		// 收货地址
		String goodsReceiptPlace = requestMap.get(Constants.bill_goods_receipt_place);
		// 核验时间半径
		String verificationTimeRadius = requestMap.get(Constants.bill_verification_time_radius);

		if (vehicleNumber == null || StringUtils.isEmpty(vehicleNumber)) {
			emptyList.add(Constants.bill_vehicleNumber);
		} else {
			if (!checkPlateNumber(vehicleNumber)) {
				errorList.add(Constants.bill_vehicleNumber);
			}
		}

		if (vehiclePlateColorCode == null || StringUtils.isEmpty(vehiclePlateColorCode)) {
			emptyList.add(Constants.bill_vehiclePlateColorCode);
		} else {
			if (!checkPlateColor(vehiclePlateColorCode)) {
				errorList.add(Constants.bill_vehiclePlateColorCode);
			}
		}

		if (receiptCountrySubdivisionCode == null || StringUtils.isEmpty(receiptCountrySubdivisionCode)) {
			emptyList.add(Constants.bill_receipt_country_subdivision_code);
		} else {
			if (!checkNumber(receiptCountrySubdivisionCode)) {
				errorList.add(Constants.bill_receipt_country_subdivision_code);
			}
		}

		if (goodsReceiptDateTime == null || StringUtils.isEmpty(goodsReceiptDateTime)) {
			emptyList.add(Constants.bill_goodsReceiptDateTime);
		} else {
			if(!checkDateTime(goodsReceiptDateTime,"yyyyMMddHHmmss")){
				errorList.add(Constants.bill_goodsReceiptDateTime);
			}
		}

		if (loadingCountrySubdivisionCode == null || StringUtils.isEmpty(loadingCountrySubdivisionCode)) {
			emptyList.add(Constants.bill_loading_country_subdivision_code);
		} else {
			if (!checkNumber(loadingCountrySubdivisionCode)) {
				errorList.add(Constants.bill_loading_country_subdivision_code);
			}
		}

		if (despatchActualDateTime == null || StringUtils.isEmpty(despatchActualDateTime)) {
			emptyList.add(Constants.bill_despatchActualDateTime);
		} else {
			if(!checkDateTime(despatchActualDateTime,"yyyyMMddHHmmss")){
				errorList.add(Constants.bill_despatchActualDateTime);
			}
		}

		if (shippingNoteNumber == null || StringUtils.isEmpty(shippingNoteNumber)) {
			emptyList.add(Constants.bill_shipping_note_number);
		}
		if (placeOfLoading == null || StringUtils.isEmpty(placeOfLoading)) {
			emptyList.add(Constants.bill_place_of_loading);
		}
		if (goodsReceiptPlace == null || StringUtils.isEmpty(goodsReceiptPlace)) {
			emptyList.add(Constants.bill_goods_receipt_place);
		}
		if (verificationTimeRadius == null || StringUtils.isEmpty(verificationTimeRadius)) {
			emptyList.add(Constants.bill_verification_time_radius);
		}
		Map<String, Object> resultMap = new HashMap<>();
		if(emptyList.size() == 0 && errorList.size() == 0) {
			resultMap.put(Constants.zxh_vehicleNumber,vehicleNumber);
			resultMap.put(Constants.zxh_vehiclePlateColorCode,vehiclePlateColorCode);
			resultMap.put(Constants.zxh_receiptCountrySubdivisionCode, receiptCountrySubdivisionCode);
			resultMap.put(Constants.zxh_goodsReceiptDateTime, goodsReceiptDateTime);
			resultMap.put(Constants.zxh_loadingCountrySubdivisionCode, loadingCountrySubdivisionCode);
			resultMap.put(Constants.zxh_despatchActualDateTime, despatchActualDateTime);
			return resultMap;
		}
		return null;
	}

	// 校验项 车辆历史轨迹核验（运单详版）
	public Map<String, Object> waybillHistoryPosition(Map<String, String> requestMap, Set<String> emptyList, Set<String> errorList){
		log.info("requestMap:{}", requestMap);
		// 车牌号校验
		Object vehicleInfo = requestMap.get(Constants.bill_vehicleInfo);
		log.info("vehicleInfo:{}", vehicleInfo);
		JSONObject vehicleInfoObject = new JSONObject();
		Map<String, Object> resultMap = new HashMap<String, Object>();
		if (vehicleInfo == null) {
			emptyList.add(Constants.bill_vehicleInfo);
		} else {
			vehicleInfoObject = JSON.parseObject(JSON.toJSONString(vehicleInfo));
		}
		log.info("vehicleInfoObject:{}", vehicleInfoObject);
		// 车牌号
		String vehicleNumber = vehicleInfoObject.getString(Constants.bill_vehicleNumber);
		// 车牌颜色
		String vehiclePlateColorCode = vehicleInfoObject.getString(Constants.bill_vehiclePlateColorCode);
		// 收货地址的国家行政区划代码
		String receiptCountrySubdivisionCode = vehicleInfoObject.getString(Constants.bill_receipt_country_subdivision_code);
		// 收货日期时间
		String goodsReceiptDateTime = requestMap.get(Constants.bill_goodsReceiptDateTime);
		// 装货地址的国家行政区划代码
		String loadingCountrySubdivisionCode = vehicleInfoObject.getString(Constants.bill_loading_country_subdivision_code);
		// 发货日期时间
		String despatchActualDateTime = requestMap.get(Constants.bill_despatchActualDateTime);

		log.info("获取参数");
		if (vehicleNumber == null || StringUtils.isEmpty(vehicleNumber)) {
			emptyList.add(Constants.bill_vehicleInfo + "." + Constants.bill_vehicleNumber);
		} else {
			if (!checkPlateNumber(vehicleNumber)) {
				errorList.add(Constants.bill_vehicleInfo + "." + Constants.bill_vehicleNumber);
			}
		}

		if (vehiclePlateColorCode == null || StringUtils.isEmpty(vehiclePlateColorCode)) {
			emptyList.add(Constants.bill_vehicleInfo + "." + Constants.bill_vehiclePlateColorCode);
		} else {
			if (!checkPlateColor(vehiclePlateColorCode)) {
				errorList.add(Constants.bill_vehicleInfo + "." + Constants.bill_vehiclePlateColorCode);
			}
		}

		if (receiptCountrySubdivisionCode == null || StringUtils.isEmpty(receiptCountrySubdivisionCode)) {
			emptyList.add(Constants.bill_vehicleInfo + "." + Constants.bill_receipt_country_subdivision_code);
		} else {
			if (!checkNumber(receiptCountrySubdivisionCode)) {
				errorList.add(Constants.bill_vehicleInfo + "." + Constants.bill_receipt_country_subdivision_code);
			}
		}

		if (goodsReceiptDateTime == null || StringUtils.isEmpty(goodsReceiptDateTime)) {
			emptyList.add(Constants.bill_goodsReceiptDateTime);
		} else {
			if(!checkDateTime(goodsReceiptDateTime,"yyyyMMddHHmmss")){
				errorList.add(Constants.bill_goodsReceiptDateTime);
			}
		}

		if (loadingCountrySubdivisionCode == null || StringUtils.isEmpty(loadingCountrySubdivisionCode)) {
			emptyList.add(Constants.bill_vehicleInfo + "." + Constants.bill_loading_country_subdivision_code);
		} else {
			if (!checkNumber(loadingCountrySubdivisionCode)) {
				errorList.add(Constants.bill_vehicleInfo + "." + Constants.bill_loading_country_subdivision_code);
			}
		}

		if (despatchActualDateTime == null || StringUtils.isEmpty(despatchActualDateTime)) {
			emptyList.add(Constants.bill_despatchActualDateTime);
		} else {
			if(!checkDateTime(despatchActualDateTime,"yyyyMMddHHmmss")){
				errorList.add(Constants.bill_despatchActualDateTime);
			}
		}
		log.info("参数校验");

		if (emptyList.size() == 0 && errorList.size() == 0) {
			resultMap.put(Constants.zxh_vehicleNumber,vehicleNumber);
			resultMap.put(Constants.zxh_vehiclePlateColorCode,vehiclePlateColorCode);
			resultMap.put(Constants.zxh_receiptCountrySubdivisionCode, receiptCountrySubdivisionCode);
			resultMap.put(Constants.zxh_goodsReceiptDateTime, goodsReceiptDateTime);
			resultMap.put(Constants.zxh_loadingCountrySubdivisionCode, loadingCountrySubdivisionCode);
			resultMap.put(Constants.zxh_despatchActualDateTime, despatchActualDateTime);
			log.info("参数拼接");
			return resultMap;
		}
		log.info("参数校验失败");
		return null;
	}

	public static boolean checkPlateColor(String plateColor) {
		String[] vehiclePlateColorCodeArr = {"1", "2", "3", "4", "5", "9", "91", "92", "93", "94"};
		return ArrayUtils.contains(vehiclePlateColorCodeArr, plateColor);
	}

	public static boolean checkNumber(String number) {
		String NUMBER_REGEX = "^(0|[1-9]\\d*)$";
		Pattern numberPattern = Pattern.compile(NUMBER_REGEX);
		return numberPattern.matcher(number).matches();
	}

	public static boolean checkPlateNumber(String plateNumber) {
		String CAR_NUMER_REGEX = "^[京津沪渝冀豫云辽黑湘皖鲁新苏浙赣鄂桂甘晋蒙陕吉闽贵粤青藏川宁琼使领A-Z]{1}[A-Z]{1}" +
				"[警京津沪渝冀豫云辽黑湘皖鲁新苏浙赣鄂桂甘晋蒙陕吉闽贵粤青藏川宁琼]{0,1}[A-Z0-9]{4,6}[A-Z0-9挂学警港澳]{1}$";
		Pattern pattern = Pattern.compile(CAR_NUMER_REGEX);
		return pattern.matcher(plateNumber).matches();
	}

	public static boolean checkDateTime(String str, String pattern) {
		DateTimeFormatter dtf = DateTimeFormatter.ofPattern(pattern);
		boolean flag = true;
		try {
			LocalDateTime.parse(str, dtf);
		} catch (Exception e) {
			flag = false;
		}
		return flag;
	}

	public static String transferDate(String str, String oldpattern, String newPattern) {
		DateTimeFormatter dtf = DateTimeFormatter.ofPattern(oldpattern);
		DateTimeFormatter newdtf = DateTimeFormatter.ofPattern(newPattern);
		try {
			String result = newdtf.format(dtf.parse(str));
			return result;
		} catch (Exception e) {
			log.error("Exception:{}", e);
			return null;
		}
	}

	public Set<String> resultTransferParam(String productCode, Set<String> list) {
		Set<String> result = new HashSet<String>();
		if ("04".equals(productCode)) {
			// 人员从业资格验证
			for (String param : list) {

				if (Constants.rycyzgyz_nameOfPerson.equals(param)) {
					result.add(Constants.driver_driverNamer);
				}
				if (Constants.rycyzgyz_qualificationCertificateNumber.equals(param)) {
					result.add(Constants.driver_qualificationCertificate);
				}
				if (Constants.rycyzgyz_provinceCode.equals(param)) {
					result.add(Constants.driver_provinceCode);
				}
				if (Constants.rycyzgyz_periodStartDate.equals(param)) {
					result.add(Constants.driver_qualificationCertificateFrom);
				}
				if (Constants.rycyzgyz_periodEndDate.equals(param)) {
					result.add(Constants.driver_qualificationCertificateTo);
				}
			}

		} else if ("02".equals(productCode)) {// 车辆营运验证
			for (String param : list) {

				if (Constants.clyyyz_vehicleNumber.equals(param)) {
					result.add(Constants.car_vehicleNumber);
				}
				if (Constants.clyyyz_licensePlateTypeCode.equals(param)) {
					result.add(Constants.car_vehiclePlateColorCode);
				}
				if (Constants.clyyyz_roadTransportCertificateNumber.equals(param)) {
					result.add(Constants.car_roadTransport);
				}
				if (Constants.clyyyz_periodStartDate.equals(param)) {
					result.add(Constants.car_roadTransportCertificateValidPeriodFrom);
				}
				if (Constants.clyyyz_periodEndDate.equals(param)) {
					result.add(Constants.car_roadTransportCertificateValidPeriodTo);
				}
			}
		} else if ("10".equals(productCode)) {// 企业经营许可验证 经营许可证号

			for (String param : list) {

				if (Constants.qyyyxkz_carrier.equals(param)) {
					result.add(Constants.bill_carrier);
				}
				if (Constants.qyyyxkz_permitNumber.equals(param)) {
					result.add(Constants.bill_permitNumber);
				}
				if (Constants.qyyyxkz_provinceCode.equals(param)) {
					result.add(Constants.bill_carrier);
					/* result.add(Constants.bill_unifiedSocialCreditIdentifier); */
				}
				/*
				 * if (Constants.clyyyz_periodStartDate.equals(param)) {
				 * result.add(Constants.bill_permitValidPeriodFrom);
				 *
				 * } if (Constants.clyyyz_periodEndDate.equals(param)) {
				 * result.add(Constants.bill_permitValidPeriodTo);
				 *
				 * }
				 */
				if (Constants.qyyyxkz_name.equals(param)) {
					result.add(Constants.bill_carrier);
				}
				/*
				 * if (Constants.qyyyxkz_creditCode.equals(param)) {
				 * result.add(Constants.bill_unifiedSocialCreditIdentifier); }
				 */
			}
		} else if ("09".equals(productCode)) {// 车辆入网验证

			for (String param : list) {

				if (Constants.clrw_vehicleNumber.equals(param)) {
					result.add(Constants.bill_vehicleInfo + "." + Constants.bill_vehicleNumber);
				}
				if (Constants.clrw_licensePlateTypeCode.equals(param)) {
					result.add(Constants.bill_vehicleInfo + "." + Constants.bill_vehiclePlateColorCode);
				}
			}
		} else if ("07".equals(productCode)) {// 托运人身份验证（个人）
			for (String param : list) {

				if (Constants.persontyr_name.equals(param)) {
					result.add(Constants.bill_consignorInfo + "." + Constants.bill_consignor);
				}
				if (Constants.persontyr_idCode.equals(param)) {
					result.add(Constants.bill_consignorInfo + "." + Constants.bill_ConsignorID);
				}

			}
		} else if ("08".equals(productCode)) {// 托运人身份验证（企业）
			for (String param : list) {

				if (Constants.enterpricetyr_name.equals(param)) {
					result.add(Constants.bill_consignorInfo + "." + Constants.bill_consignor);
				}
				if (Constants.enterpricetyr_creditCode.equals(param)) {
					result.add(Constants.bill_consignorInfo + "." + Constants.bill_ConsignorID);
				}
			}
		} else if ("05".equals(productCode)) {// 装货点车辆定位验证
			for (String param : list) {

				if (Constants.zh_xh_vehicleNumber.equals(param)) {
					result.add(Constants.bill_vehicleNumber);
				}
				if (Constants.zh_xh_countrySubdivisionCode.equals(param)) {
					result.add(Constants.bill_consignorInfo + "." + Constants.bill_countrySubdivisionCode);
				}
				if (Constants.zh_xh_dateTime.equals(param)) {
					result.add(Constants.bill_despatchActualDateTime);
				}
			}
		} else if ("06".equals(productCode)) {// 卸货点车辆定位验证

			for (String param : list) {

				if (Constants.zh_xh_vehicleNumber.equals(param)) {
					result.add(Constants.bill_vehicleNumber);
				}
				if (Constants.zh_xh_countrySubdivisionCode.equals(param)) {
					result.add(Constants.bill_consigneeInfo + "." + Constants.bill_countrySubdivisionCode);
				}
				if (Constants.zh_xh_dateTime.equals(param)) {
					result.add(Constants.bill_goodsReceiptDateTime);
				}
			}
		} else if ("12".equals(productCode)) {// 超载核验

			for (String param : list) {

				if (Constants.zlhy_vehicleNumber.equals(param)) {
					result.add(Constants.bill_vehicleInfo + "." + Constants.bill_vehicleNumber);
				}
				if (Constants.zlhy_licensePlateTypeCode.equals(param)) {
					result.add(Constants.bill_vehicleInfo + "." + Constants.car_vehiclePlateColorCode);
				}
				if (Constants.zlhy_vehicleTonnage.equals(param)) {
					result.add(Constants.bill_vehicleInfo + "." + Constants.bill_goodsInfo + "."
							+ Constants.bill_goodsInfo_weight);
				}
			}
		} else if ("13".equals(productCode)) {// 司机上下线
			for (String param : list) {

				if (Constants.sjsxx_bill_no.equals(param)) {
					result.add(Constants.bill_shipping_note_number);
				}
				if (Constants.sjsxx_name.equals(param)) {
					result.add(Constants.bill_vehicleInfo + "." + Constants.bill_driver + "."
							+ Constants.bill_driver_name);
				}
				if (Constants.sjsxx_idCode.equals(param)) {
					result.add(Constants.bill_vehicleInfo + "." + Constants.bill_driver + "."
							+ Constants.bill_driver_License);

				}
				if (Constants.sjsxx_H1.equals(param)) {
					result.add(Constants.bill_vehicleInfo + "." + Constants.bill_driver + "."
							+ Constants.bill_driver_License);
					result.add(Constants.bill_vehicleInfo + "." + Constants.bill_driver + "."
							+ Constants.bill_driver_name);
				}
				if (Constants.sjsxx_dateTime.equals(param) || Constants.sjsxx_despatchActualDateTime.equals(param)) {
					result.add(Constants.bill_despatchActualDateTime);
				}
				if (Constants.sjsxx_consistent.equals(param)) {
					result.add("活体核验结果");
				}
			}
		} else if ("113".equals(productCode)) {// 人员核验

			for (String param : list) {

				if (Constants.up_driverName.equals(param)) {
					result.add(Constants.perck_driverName);
				}
				if (Constants.up_certificate.equals(param)) {
					result.add(Constants.perck_certificate);
				}
				if (Constants.up_drivingLicense.equals(param)) {
					result.add(Constants.perck_drivingLicense);
				}
				if(Constants.up_provinceCode.equals(param)){
					result.add(Constants.perck_provinceCode);
				}
			}
		} else if ("115".equals(productCode)) {// 企业核验

			for (String param : list) {

				if (Constants.up_name.equals(param)) {
					result.add(Constants.comck_name);
				}
				if (Constants.up_permitNumber.equals(param)) {
					result.add(Constants.comck_permitNumber);
				}
				if (Constants.up_cprovinceCode.equals(param)) {
					result.add(Constants.comck_provinceCode);
				}
			}
		} else {
			result = list;
		}
		return result;
	}
	public boolean checkColor(String colorParm){
		 	String color="1,2,3,4,5,9,91,92,93,94";
		 	List<String> colorList = Arrays.asList(color.split(","));
		return colorList.contains(colorParm);
	}
	public boolean checkProvince(String provinceParam){

		String province="110000,120000,130000,140000,150000,210000,220000,230000,310000,320000,330000,340000,350000,360000,370000,410000,420000,430000,440000,"+
				"450000,460000,500000,510000,520000,530000,540000,610000,620000,630000,640000,650000,710000,810000,820000";
		List<String> provinceList = Arrays.asList(province.split(","));
		return provinceList.contains(provinceParam);
	}

	public static void main(String[] args) {
		String certificateNumberReg = "[0-9a-zA-Z]{1,20}";
		Pattern certificateNumberPattern = Pattern.compile(certificateNumberReg);
		log.info("{}",certificateNumberPattern.matcher("00000000000000000").matches());
	}

}
