package info.aspirecn.iov.yysj.check.info.common;
import info.aspirecn.cloud.yysj.commons.lang.Constants;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.beans.IntrospectionException;
import java.beans.PropertyDescriptor;
import java.lang.reflect.Field;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.lang.reflect.Modifier;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.regex.Pattern;


public class Validate {

    private static final Logger log = LoggerFactory.getLogger(Validate.class);

    private static final Pattern mebilePattern = Pattern.compile("^[+]{0,1}[0]{0,2}(86){0,1}1((3[4-9])|(4[7])|(5[0-2|7-9])|(8[23478])|(7[8])|(9[8]))[0-9]{8}$");

    private static final Pattern ipPattern = Pattern.compile("^(?:(?:1[0-9][0-9]\\.)|(?:2[0-4][0-9]\\.)|(?:25[0-5]\\.)|(?:[1-9][0-9]\\.)|(?:[0-9]\\.)){3}(?:(?:1[0-9][0-9])|(?:2[0-4][0-9])|(?:25[0-5])|(?:[1-9][0-9])|(?:[0-9]))$");

    private static final Pattern invaildSymbolPattern = Pattern.compile("\n|\r|\t");

    private static final Pattern numberPattern = Pattern.compile("^[0-9]*$");

    public static <T> boolean validate(T t) throws ResultCodeException, IntrospectionException, InvocationTargetException, IllegalAccessException {
        if (null == t) {
            return false;
        }
        Class<?> clazz = t.getClass();
        Field[] fields = clazz.getDeclaredFields();

        for (Field field : fields) {
            if (!Modifier.isFinal(field.getModifiers())) {
                Object fieldValue = null;
                PropertyDescriptor propertyDescriptor = new PropertyDescriptor(field.getName(), clazz);
                Method method = propertyDescriptor.getReadMethod();
                fieldValue = method.invoke(t);
                if (field.isAnnotationPresent(NonFixedValueAttr.class)) {
                    NonFixedValueAttr anno = field.getAnnotation(NonFixedValueAttr.class);
                    validateNonFixedValue(field.getName(),fieldValue, anno);
                }
            }
        }
        return true;
    }

    private static void validateNonFixedValue(String fieldName,Object fieldValue,
                                                 NonFixedValueAttr anno) throws ResultCodeException {
        if (null != fieldValue && !"".equals(fieldValue)) {
            String str = fieldValue.toString();
            if (anno.isDate()) {
                SimpleDateFormat format = new SimpleDateFormat(
                    anno.dateFormatString());
                format.setLenient(false);
                try {
                    format.parse(str);
                } catch (ParseException e) {
                    throw  new ResultCodeException(Constants.ResultDesc.PARAMERROR.getCode(),Constants.ResultDesc.PARAMERROR.getValue(),fieldName+"-"+fieldValue+"根式不正确");
                }
            }
        }
    }
}
