package info.aspirecn.iov.yysj.check.info.pre;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.netflix.zuul.ZuulFilter;
import com.netflix.zuul.context.RequestContext;
import info.aspirecn.cloud.yysj.commons.lang.Constants;
import info.aspirecn.cloud.yysj.commons.lang.OtherCommonResult;
import info.aspirecn.cloud.yysj.commons.lang.ProductCheckRequest;
import info.aspirecn.iov.yysj.check.info.common.*;
import info.aspirecn.iov.yysj.check.info.entity.BillResultObject;
import info.aspirecn.iov.yysj.check.info.entity.CheckDetailLogObject;
import info.aspirecn.iov.yysj.paramtransfer.inter.YysjUserActionInterface;
import info.aspirecn.iov.yysj.paramtransfer.inter.vo.YysjProduct;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.netflix.zuul.filters.support.FilterConstants;

import javax.servlet.http.HttpServletRequest;
import java.util.*;

/**
 *
 */
@Slf4j
public class EIDInforFilter extends ZuulFilter {

	@Autowired
	private ObjectMapper mapper;
	@Autowired
	private OtherRibbonHandle channelRibbonHandle;
	@Autowired
	private ZuulHelper helper;
	@Autowired
	private YysjUserActionInterface yysjUserActionInterface;
	@Autowired
	private TransferParam transferParam;
	@Override
	public boolean shouldFilter() {
		RequestContext requestContext = RequestContext.getCurrentContext();
		String url = requestContext.getRequest().getRequestURI();
		String livingUrl = Constants.OtherRquestUrl.LIVINGURL.getValue();
		String indetifyUrl = Constants.OtherRquestUrl.IDLENTITYVERIFICATION.getValue();
        return CommonUtil.isContinue() && (livingUrl.equals(url)||indetifyUrl.equals(url));
	}

	@Override
	public Object run() {




		RequestContext requestContext = RequestContext.getCurrentContext();

		String traceId = (String)requestContext.get(Constants.HEADER_TRACEID_KEY);
		HttpServletRequest request = requestContext.getRequest();
		requestContext.set(Constants.Url,request.getRequestURI());
		String userId = request.getHeader(Constants.HEADER_USER_ID);
		String url = requestContext.getRequest().getRequestURI();
		int type = helper.getType(url);
		BillResultObject billResultObject = new BillResultObject();
		String consistent = Constants.error;
		try{
			billResultObject.setResultCode(Constants.ResultDesc.SUCCESS.getCode());
			billResultObject.setResultMsg("成功");
			billResultObject.setTraceId(traceId);
			try {
				List<YysjProduct> yysjProducts =yysjUserActionInterface.getYysjProductIdByUserId(userId,type);
				if(yysjProducts==null || yysjProducts.size()==0){
					throw new ResultCodeException(Constants.ResultDesc.NO_PERMISSION.getCode(),"未订购核验项","根据类型和用户没有获取到校验资格项");

				}
				YysjProduct yysjProduct = yysjProducts.get(0);
				Map<String,String> map = (Map<String,String>)requestContext.get("bodyMap");

				String token = (String) requestContext.get(Constants.HEADER_TOKEN_KEY);
				List<CheckDetailLogObject>  checkDetails = new ArrayList<CheckDetailLogObject>();
				Set<String> emptyList = new HashSet<>();
				Set<String> erroList = new HashSet<>();

					Map<String,Object> cutomeMap=  transferParam.getCustomBody(map,url,emptyList,erroList);
					if(emptyList.size()!=0){
						String emptyNode = StringUtils.joinWith(",",emptyList.toArray());
						throw new ResultCodeException(Constants.ResultDesc.PARAMNULL.getCode(),emptyNode+"必填项为空","存在空值在必须校验的项上"+emptyNode);

					}
					if(erroList.size()!=0){
						String emptyNode = StringUtils.joinWith(",",erroList.toArray());
						throw new ResultCodeException(Constants.ResultDesc.PARAMERROR.getCode(),emptyNode+"参数不符合规格","存在错误的校验项上"+emptyNode);

					}



					ProductCheckRequest productCheckRequest = new ProductCheckRequest();
					productCheckRequest.setYysjProductId(yysjProduct.getYysjProductId());
					List<String> list = yysjProduct.getSjjhProductId();
					productCheckRequest.setSjjhProductId(list);
					productCheckRequest.setCustomBody(cutomeMap);
					String requestBody = mapper.writeValueAsString(productCheckRequest);

					OtherCommonResult otherCommonResult = channelRibbonHandle.channelRibbonHandle(token, requestBody, userId, traceId, yysjProduct.getYysjProductId());

					CheckDetailLogObject checkDetailLogObject = new CheckDetailLogObject();
				    checkDetailLogObject.setProductId(yysjProduct.getYysjProductId());
					if(Constants.consistent_code.equals(otherCommonResult.getResultCode())||Constants.inconsistent_code.equals(otherCommonResult.getResultCode())) {
						consistent = otherCommonResult.getResultCode();
						billResultObject.setData(otherCommonResult.getResultBody());
						String result = mapper.writeValueAsString(otherCommonResult.getResultBody());
						checkDetailLogObject.setResult(result);
					}else if(Constants.xysj_error.equals(otherCommonResult.getResultCode())){//网关失败，返回信用内部错误
						throw new ResultCodeException(Constants.ResultDesc.SERVERERROR.getCode(),Constants.ResultDesc.SERVERERROR.getValue(),"信用数据内部错误");
					}else if(Constants.error.equals(otherCommonResult.getResultCode())){//异常返回失败
						throw new ResultCodeException(Constants.ResultDesc.FAIL.getCode(),Constants.ResultDesc.FAIL.getValue(),"系统处理异常");
					}else if(Constants.param_error.equals(otherCommonResult.getResultCode())){//参数错误
						throw new ResultCodeException(Constants.ResultDesc.PARAMERROR.getCode(),Constants.ResultDesc.PARAMERROR.getValue(),"参数错误");
					}
					checkDetails.add(checkDetailLogObject);






				request.setAttribute("consistent",consistent);
				request.setAttribute("userId",userId);
				String   checkDetailsStr = mapper.writeValueAsString(checkDetails);
				request.setAttribute("CheckDetails",checkDetailsStr);
		} catch (ResultCodeException ex){
			log.error("resultCodeException:{}",ex);
			billResultObject.setResultCode(ex.getCode());
			billResultObject.setResultMsg(ex.getMessage());
		}catch (Exception ex) {
			log.error("Exception:{}",ex);
			billResultObject.setResultCode(Constants.ResultDesc.SERVERERROR.getCode());
			billResultObject.setResultMsg(Constants.ResultDesc.SERVERERROR.getValue());
		}
		helper.responseHandle(billResultObject, requestContext,false);
	}catch (JsonProcessingException e) {
			log.error("解析对象出错,message:{}", e);
		}
		return null;

	}

	@Override
	public String filterType() {
		return FilterConstants.PRE_TYPE;
	}

	@Override
	public int filterOrder() {
		return FilterConstants.SERVLET_30_WRAPPER_FILTER_ORDER + 4;
	}

}
