package info.aspirecn.iov.yysj.check.info.pre;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.netflix.zuul.ZuulFilter;
import com.netflix.zuul.context.RequestContext;
import info.aspirecn.cloud.yysj.commons.lang.Constants;
import info.aspirecn.iov.yysj.check.info.common.CommonUtil;
import info.aspirecn.iov.yysj.check.info.common.ZuulHelper;
import info.aspirecn.iov.yysj.check.info.entity.BillResultObject;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.netflix.zuul.filters.support.FilterConstants;

import java.util.ArrayList;
import java.util.HashMap;

/**
 * 屏蔽除了/info_check/waybill.do;/info_check/carInfo.do;/info_check/driverInfo.do的请求
 */
@Slf4j
public class InterfaceFilter extends ZuulFilter {
	@Autowired
	private ZuulHelper zuulHelper;
	@Override
	public boolean shouldFilter() {
		RequestContext requestContext = RequestContext.getCurrentContext();
		String url = requestContext.getRequest().getRequestURI();
		requestContext.getRequest().setAttribute("paramBody",new HashMap());
		requestContext.getRequest().setAttribute("queryParam",new HashMap());
		requestContext.getRequest().setAttribute("CheckDetails",new ArrayList<>());
		log.info("InterfaceFilter-url:{},CommonUtil.checkAllUrl:{}", url, CommonUtil.checkAllUrl(url));
		return  !CommonUtil.checkAllUrl(url)&&!CommonUtil.checkRoadTransUrl(url);
	}

	@Override
	public Object run() {
		RequestContext requestContext = RequestContext.getCurrentContext();
		String url = requestContext.getRequest().getRequestURI();
		log.error("当前没有满足条件的接口,请求地址:{}",url);
		BillResultObject responseObject = new BillResultObject();
		responseObject.setResultCode(Constants.ResultDesc.HTTPMETHODERROR.getCode());
		responseObject.setResultMsg(Constants.ResultDesc.HTTPMETHODERROR.getValue());
		String traceId = (String)requestContext.get(Constants.HEADER_TRACEID_KEY);
		responseObject.setTraceId(traceId);
		try {
			zuulHelper.responseHandle(responseObject, requestContext,false);
		} catch (JsonProcessingException e) {
			log.error("解析json失败,message:{}", e);
		}
		return null;
	}

	@Override
	public String filterType() {
		return FilterConstants.PRE_TYPE;
	}

	@Override
	public int filterOrder() {
		return FilterConstants.SERVLET_30_WRAPPER_FILTER_ORDER+2;
	}
}
