package info.aspirecn.iov.yysj.check.info.pre;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.netflix.zuul.ZuulFilter;
import com.netflix.zuul.context.RequestContext;
import info.aspirecn.cloud.yysj.commons.lang.Constants;
import info.aspirecn.iov.yysj.check.info.common.*;
import info.aspirecn.iov.yysj.check.info.entity.BillResultObject;
import info.aspirecn.iov.yysj.check.info.entity.RoadTransportObject;
import info.aspirecn.iov.yysj.check.info.entity.RoadTransportObject.VerifyResultSet;
import info.aspirecn.iov.yysj.check.info.entity.RoadTransportObject.VerifyResultSet.Errorresult;
import info.aspirecn.iov.yysj.paramtransfer.inter.YysjUserActionInterface;
import info.aspirecn.iov.yysj.paramtransfer.inter.vo.YysjUser;
import io.jsonwebtoken.SignatureAlgorithm;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.netflix.zuul.filters.support.FilterConstants;
import org.springframework.data.redis.core.StringRedisTemplate;

import javax.servlet.http.HttpServletRequest;
import java.util.Calendar;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.concurrent.TimeUnit;

/**
 * 获取到请求参数，并进行验签，和headers的校验
 */
@Slf4j
public class RequestBodyFilter extends ZuulFilter {

	@Autowired
	private Property property;
	@Autowired
	private StringRedisTemplate stringRedisTemplate;
	@Autowired
	private YysjUserActionInterface yysjUserActionInterface;
	@Autowired
	private ObjectMapper mapper;
	@Autowired
	private ZuulHelper helper;
	@Override
	public boolean shouldFilter() {
		RequestContext requestContext = RequestContext.getCurrentContext();
		String url = requestContext.getRequest().getRequestURI();
		boolean isExist =  (CommonUtil.checkAllUrl(url) || CommonUtil.checkRoadTransUrl(url))&& CommonUtil.isContinue();
		return isExist;
	}

	@Override
	public Object run() {

		RequestContext requestContext = RequestContext.getCurrentContext();
		HttpServletRequest request = requestContext.getRequest();
		String url = request.getRequestURI();
		String userId = request.getHeader(Constants.HEADER_USER_ID);
		String body = CommonUtil.getBody(request);
		BillResultObject responseObject= new BillResultObject();



		try {
			try{
				if(body==null){
					throw new ResultCodeException(Constants.ResultDesc.PARAMNULL.getCode(),"request body必填项为空","request body为空");
				}
                Map<String, String> map = null;
				log.info("body:{}",body);
				String logBody ="";
                try {
						logBody = helper.divYunDan(body);
					map = mapper.readValue(body,Map.class);

                }catch (Exception ex){
                	log.error("ex:{}",ex);
                    throw new ResultCodeException(Constants.ResultDesc.PARAMERROR.getCode(), "request body参数不符合规格", "request body格式不正确");
                }

                requestContext.set("bodyMap",map);
                requestContext.set(Constants.BODY,body);
                String queryParam = helper.queryParam(url,map);
                //设置请求参数信息和全量请求参数
				request.setAttribute("queryParam",new String(queryParam.getBytes("utf-8"),"utf-8"));
				request.setAttribute("paramBody",new String(logBody.getBytes("utf-8"),"utf-8"));
				//根据userId查询appid和appscret
                if(StringUtils.isEmpty(userId)){
                    throw new ResultCodeException(Constants.ResultDesc.PARAMNULL.getCode(),"LOGINK-USER-ID必填项为空","LOGINK-USER-ID没有值");
                }
				YysjUser yysjUser = yysjUserActionInterface.getUser(userId);
                if(yysjUser==null){
					throw new ResultCodeException(Constants.ResultDesc.NO_PERMISSION.getCode(),"未开通云雁服务","未开通云雁服务");
				}



				String appId = yysjUser.getAppId();
				String appSecret = yysjUser.getSecret();



				String productIds = "";
				String token ="";
				Map<String, Object> claims = new HashMap<>();
				String tokenInfo = stringRedisTemplate.boundValueOps("sjjhcore::getToken_"+appId+"_"+appSecret).get();

				if(tokenInfo!=null){
					String[] tokenInfos = tokenInfo.split("_");
					claims.put("userId", tokenInfos[0]);
					claims.put("productIds",tokenInfos[1]);
					Calendar calendar = Calendar.getInstance();
					calendar.add(Calendar.MINUTE, 30);
					productIds = tokenInfos[1];
					token = JWTUtils.generateToken(claims, property.getTokenSecret(), calendar.getTime(), SignatureAlgorithm.HS256);

				}else {
						claims.put("userId", String.valueOf(yysjUser.getSjjhUserId()));
						//从数据库获取数据交互的产品id
						List<String> products = yysjUserActionInterface.getSjjhProduct();


						if(products ==null || products.size()==0){
							throw new ResultCodeException(Constants.ResultDesc.SERVERERROR.getCode(),Constants.ResultDesc.SERVERERROR.getValue(),"数据交互列表为空");
						}
						productIds = StringUtils.join(products, ",");
						claims.put("productIds", productIds);
						Calendar calendar = Calendar.getInstance();
						calendar.add(Calendar.MINUTE, 30);
						token = JWTUtils.generateToken(claims, property.getTokenSecret(), calendar.getTime(), SignatureAlgorithm.HS256);
						stringRedisTemplate.boundValueOps("sjjhcore::getToken_" + appId + "_" + appSecret).set(yysjUser.getSjjhUserId() + "_" + productIds);
						stringRedisTemplate.boundValueOps("sjjhcore::getToken_" + appId + "_" + appSecret).expire(30, TimeUnit.MINUTES);

				}

				requestContext.set(Constants.HEADER_TOKEN_KEY,token);
				requestContext.set(Constants.PRODUCTIDS_KEY,productIds);
				return null;
			} catch (ResultCodeException ex){
				log.error("resultCodeException:{}",ex);


					responseObject.setResultCode(ex.getCode());
					responseObject.setResultMsg(ex.getMessage());
					responseObject.setTraceId((String)requestContext.get(Constants.HEADER_TRACEID_KEY));



			}catch (Exception ex) {
				log.error("Exception:{}",ex);

					responseObject.setResultCode(Constants.ResultDesc.SERVERERROR.getCode());
					responseObject.setResultMsg(Constants.ResultDesc.SERVERERROR.getValue());
					responseObject.setTraceId((String)requestContext.get(Constants.HEADER_TRACEID_KEY));

			}
			helper.responseHandle(responseObject,requestContext,false);
		} catch (JsonProcessingException e) {
			log.error("解析对象出错,message:{}", e);
		}

		return null;


	}

	@Override
	public String filterType() {
		return FilterConstants.PRE_TYPE;
	}

	@Override
	public int filterOrder() {
		return FilterConstants.SERVLET_30_WRAPPER_FILTER_ORDER + 3;
	}
}
