package info.aspirecn.iov.yysj.check.info.pre;

import brave.Tracer;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.netflix.zuul.ZuulFilter;
import com.netflix.zuul.context.RequestContext;
import info.aspirecn.cloud.yysj.commons.lang.Constants;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.netflix.zuul.filters.support.FilterConstants;


/**
 * 向response写入x-b3-traceid信息
 * 
 * 请求header中need-x-b3-traceid存在，则返回整个链路的x-b3-traceid信息，
 * 在response写入x-b3-traceid信息
 * 
 * @author wangxinning
 *
 */
@Slf4j
public class ResponseTraceIDFilter extends ZuulFilter {

	@Autowired
	private Tracer tracer;
	@Autowired
	ObjectMapper objectMapper;

	@Override
	public boolean shouldFilter() {
		/*RequestContext requestContext = RequestContext.getCurrentContext();
		String url = requestContext.getRequest().getRequestURI();
		Pattern pattern = Pattern.compile("result.do");
		Matcher matcher = pattern.matcher(url);*/
		return (tracer != null && tracer.currentSpan() != null
                && StringUtils.isNotBlank(tracer.currentSpan().context().traceIdString()));
	}

	@Override
	public Object run() {
		RequestContext requestContext = RequestContext.getCurrentContext();
		String url = requestContext.getRequest().getRequestURI();
		String traceId = tracer.currentSpan().context().traceIdString();
		String spanId = String.valueOf(tracer.currentSpan().context().spanId());
		requestContext.getRequest().setAttribute(Constants.HEADER_TRACEID_KEY, traceId);
		requestContext.getRequest().setAttribute("x-b3-spanid", spanId);
		requestContext.set(Constants.HEADER_TRACEID_KEY,traceId);
		return null;
	}

	@Override
	public String filterType() {
		return FilterConstants.PRE_TYPE;
	}

	@Override
	public int filterOrder() {
		return FilterConstants.SERVLET_30_WRAPPER_FILTER_ORDER + 1;
	}
}