package info.aspirecn.iov.yysj.check.info.pre;

import javax.servlet.http.HttpServletRequest;
import brave.Tracer;
import com.fasterxml.jackson.core.JsonProcessingException;
import info.aspirecn.cloud.yysj.commons.lang.BillItemResult;
import info.aspirecn.cloud.yysj.commons.lang.Constants;
import info.aspirecn.cloud.yysj.commons.lang.ProductCheckRequest;
import info.aspirecn.iov.yysj.check.info.common.*;
import info.aspirecn.iov.yysj.check.info.entity.*;
import info.aspirecn.iov.yysj.paramtransfer.inter.YysjUserActionInterface;
import info.aspirecn.iov.yysj.paramtransfer.inter.vo.YysjProduct;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.netflix.zuul.filters.support.FilterConstants;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.netflix.zuul.ZuulFilter;
import com.netflix.zuul.context.RequestContext;
import lombok.extern.slf4j.Slf4j;
import java.util.*;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import info.aspirecn.iov.yysj.paramtransfer.inter.YysjUserActionInterface;
/**
 * 运单信息核验服务,
 */
@Slf4j
public class WayBillFilter extends ZuulFilter {

	@Autowired
	private Property property;
	@Autowired
	private Tracer tracer;
	@Autowired
	private ObjectMapper mapper;
	@Autowired
	private ChannelRibbonHandle channelRibbonHandle;
	@Autowired
	private ZuulHelper helper;
	@Autowired
	private YysjUserActionInterface yysjUserActionInterface;
	@Autowired
	private TransferParam transferParam;
	@Override
	public boolean shouldFilter() {
		RequestContext requestContext = RequestContext.getCurrentContext();
		String url = requestContext.getRequest().getRequestURI();
        return CommonUtil.isContinue() && CommonUtil.checkUrl(url);
	}

	@Override
	public Object run() {
		String traceId = tracer.currentSpan().context().traceIdString();
		Pattern pattern = Pattern.compile("(.*?)公司$");
		//同斥产品列表
		List<String> mutexProducts = new ArrayList<String>();
		Set<String> verifyRangeSet =  new HashSet<String>();
		BillResultObject billResultObject = new BillResultObject();
		String accessId = tracer.currentSpan().context().traceIdString();
		RequestContext requestContext = RequestContext.getCurrentContext();
		HttpServletRequest request = requestContext.getRequest();
		String url = request.getRequestURI();
		try{
		try {
			String token = (String) requestContext.get(Constants.HEADER_TOKEN_KEY);

			//根据用户id获取订购的数据交互产品信息
			String userId = request.getHeader(Constants.HEADER_USER_ID);
			int type = helper.getType(url);
			Map<String,String> map = (Map<String,String>)requestContext.get("bodyMap");
			//根据userId获取云验平台产品
			List<YysjProduct> yysjProducts =yysjUserActionInterface.getYysjProductIdByUserId(userId,type);
			if(yysjProducts==null || yysjProducts.size()==0){
				throw new ResultCodeException(Constants.ResultDesc.NO_PERMISSION.getCode(),"没有订购校验资格项","根据类型和用户没有获取到校验资格项");

			}
			String verifyRange= map.get("verifyRange");
			if(!StringUtils.isEmpty(verifyRange)){
				verifyRangeSet =new HashSet(Arrays.asList(verifyRange.split(",")));
			}
			Map<String,String> yysjProductCodeMap = property.getYysjProductCode();
			String resultCode = "1";
			List<ConcreteCheckResult> results = new ArrayList<ConcreteCheckResult>();

			Set<String> inconsistentContentItem =new HashSet<String>();
			Set<String> consistentContentItem =new HashSet<String>();
			Map<String,Map<String,Object>> cumtomBodyMap = new HashMap<String,Map<String,Object>>();
			Set<String> emptyList = new HashSet<>();
			Set<String> erroList = new HashSet<>();
			int index = 0;
			List<YysjProduct> products = new ArrayList<YysjProduct>();
			for(YysjProduct yysjProduct : yysjProducts){
				//String yysjProductCode = yysjProductCodeMap.get(yysjProduct.getYysjProductId());
				String yysjProductCode = yysjProduct.getYysjProductCode();
				if((verifyRangeSet.size()!=0 && verifyRangeSet.contains(yysjProductCode))||verifyRangeSet.size()==0){
					if("07".equals(yysjProductCode)||"08".equals(yysjProductCode)){
						mutexProducts.add(yysjProductCode);
					}
					//yysjProduct.setYysjProductCode(yysjProductCode);
					index++;
					Map<String,Object> cutomBody = transferParam.getCustomBody(map, yysjProductCode, emptyList,erroList);
					if(cutomBody!=null){
						yysjProduct.setCostomObject(cutomBody);
						cumtomBodyMap.put( yysjProduct.getYysjProductId(),cutomBody);
					}
					products.add(yysjProduct);
				}
			}
			if(emptyList.size()!=0){
				String emptyNode = StringUtils.joinWith(",",emptyList.toArray());
				throw new ResultCodeException(Constants.ResultDesc.PARAMNULL.getCode(),emptyNode+"必填项为空","存在空值在必须校验的项上"+emptyNode);

			}
			if(erroList.size()!=0){
				String emptyNode = StringUtils.joinWith(",",erroList.toArray());
				throw new ResultCodeException(Constants.ResultDesc.PARAMERROR.getCode(),emptyNode+"参数不符合规格","存在错误的校验项上"+emptyNode);

			}
			if(index ==0){
				throw new ResultCodeException(Constants.ResultDesc.PARAMERROR.getCode(),"verifyRange参数不符合规格","verifyRange与订购的校验项没有重合项");
			}
			List<CheckDetailLogObject>  checkDetails = new ArrayList<CheckDetailLogObject>();
			for(YysjProduct yysjProduct : products){
				CheckDetailLogObject checkDetailLogObject = new CheckDetailLogObject();
				checkDetailLogObject.setProductId(yysjProduct.getYysjProductId());
				ConcreteCheckResult concreteCheckResult = new ConcreteCheckResult();
				concreteCheckResult.setVerifyCode(yysjProduct.getYysjProductCode());
				concreteCheckResult.setVerifyMSG(yysjProduct.getProduceName());
				try {
					List<String> list = yysjProduct.getSjjhProductId();
					if(mutexProducts.size()>1 && (("07".equals(yysjProduct.getYysjProductCode()))||"08".equals(yysjProduct.getYysjProductCode()))){//选定了07和08,当07的时候用户信息不是以公司结尾，且长度不大于4
						Object consignorInfo = map.get(Constants.bill_consignorInfo);
						Map<String,String> consignorInfoMap =(Map<String,String>)consignorInfo;

						String consignor = consignorInfoMap.get(Constants.bill_consignor);
						Matcher matcher = pattern.matcher(consignor);
						String subStrConsignor=consignor.substring(consignor.length()-2,consignor.length());

						if((!matcher.matches()|| consignor.length()<=4)&&"08".equals(yysjProduct.getYysjProductCode())){
							continue;
						}
						if(matcher.matches()&& consignor.length()>4&&"07".equals(yysjProduct.getYysjProductCode())){
							continue;
						}
					}
					ProductCheckRequest productCheckRequest = new ProductCheckRequest();
					productCheckRequest.setYysjProductId(yysjProduct.getYysjProductId());
					productCheckRequest.setSjjhProductId(list);
					productCheckRequest.setCustomBody(yysjProduct.getCostomObject());
					String requestBody = mapper.writeValueAsString(productCheckRequest);
					log.info("requestBody:{},userId:{},traceId:{},yysjProduct.getYysjProductId:{}", requestBody, userId, traceId, yysjProduct.getYysjProductId());
					BillItemResult billItemResult = channelRibbonHandle.channelRibbonHandle(token, requestBody, userId, traceId, yysjProduct.getYysjProductId());
					log.info("billItemResult:{}", billItemResult.toString());

					concreteCheckResult.setResult("1".equals(billItemResult.getResult())?"0":"1");
					if (!"1".equals(billItemResult.getResult())) {

						resultCode = "0";
						inconsistentContentItem.add(yysjProduct.getYysjProductCode());
						BillItemResult.ErrorResponse errorResponse = billItemResult.getExceptionInformation();

						if(errorResponse.getCode() == Constants.ErrorCode.Exception.getErrorCode()){
							concreteCheckResult.setErrorInfo(Constants.errorInfo);
						}else if(errorResponse.getCode() == Constants.ErrorCode.WEIGTHOVER.getErrorCode()){
							concreteCheckResult.setErrorInfo(Constants.weightOverInfo);
						}else if(errorResponse.getCode() == Constants.ErrorCode.MONEYNOTENOUGH.getErrorCode()){
							concreteCheckResult.setErrorInfo(Constants.moneyNotEnough);
						}else {
							Set<String> resultList = errorResponse.getResultList();
							Set<String> resultSet = transferParam.resultTransferParam(yysjProduct.getYysjProductCode(),resultList);
							if (errorResponse.getCode() == Constants.ErrorCode.NULL.getErrorCode()) {
								concreteCheckResult.setErrorInfo("数据源" + StringUtils.join(resultSet.toArray(), ",") + "为空");
							} else {

								concreteCheckResult.setErrorInfo("数据源" + StringUtils.join(resultSet.toArray(), ",") + "为不一致");
							}
						}

					} else {
						consistentContentItem.add(yysjProduct.getYysjProductCode());
					}

					checkDetailLogObject.setResult(billItemResult.getResult());
				}catch (Exception ex){
					log.error("WayBillFilter,exception:{}",ex);
					concreteCheckResult.setResult("1");
					resultCode = "0";
					checkDetailLogObject.setResult("0");
					inconsistentContentItem.add(yysjProduct.getYysjProductCode());
					concreteCheckResult.setErrorInfo("系统异常");
				}
				checkDetails.add(checkDetailLogObject);
				results.add(concreteCheckResult);

			}
			Data data = new Data();
			Collections.sort(results);
			data.setVerifyResultSet(results);
			if(inconsistentContentItem.size()==0){
				data.setInconsistentMSG("");
			}else{
				data.setInconsistentMSG(StringUtils.join(new TreeSet<String>(inconsistentContentItem).toArray(), ","));
			}
			if(consistentContentItem.size()==0){
				data.setConsistentMSG("");
			}else {
				data.setConsistentMSG(StringUtils.join(new TreeSet<String>(consistentContentItem).toArray(), ","));
			}
			billResultObject.setData(data);
			billResultObject.setResultCode(Constants.ResultDesc.SUCCESS.getCode());
			billResultObject.setResultMsg("成功");
			billResultObject.setTraceId(accessId);
			//String json = mapper.writeValueAsString(billResultObject);
			request.setAttribute("consistent",resultCode);
			request.setAttribute("userId",userId);
			String   checkDetailsStr = mapper.writeValueAsString(checkDetails);
			request.setAttribute("CheckDetails",checkDetailsStr);
		} catch (ResultCodeException ex){
			log.error("resultCodeException:{}",ex.getMessage());
			billResultObject.setResultCode(ex.getCode());
			billResultObject.setResultMsg(ex.getMessage());
			billResultObject.setTraceId((String)requestContext.get(Constants.HEADER_TRACEID_KEY));
		}catch (Exception ex) {
			log.error("Exception:{}",ex.getMessage());
			billResultObject.setResultCode(Constants.ResultDesc.SERVERERROR.getCode());
			billResultObject.setResultMsg(Constants.ResultDesc.SERVERERROR.getValue());
			billResultObject.setTraceId((String) requestContext.get(Constants.HEADER_TRACEID_KEY));
		}
		helper.responseHandle(billResultObject, requestContext,false);
	}catch (JsonProcessingException e) {
			log.error("解析对象出错,message:{}", e.getMessage());
		}
		return null;

	}

	@Override
	public String filterType() {
		return FilterConstants.PRE_TYPE;
	}

	@Override
	public int filterOrder() {
		return FilterConstants.SERVLET_30_WRAPPER_FILTER_ORDER + 4;
	}

}
